@@ -1,11 +1,13 @@
-from konoha.konoha_token import Token
+from typing import List
+
+from konoha.data.token import Token
 from konoha.word_tokenizers.tokenizer import BaseTokenizer
 
 
 class SentencepieceTokenizer(BaseTokenizer):
     """Wrapper class forSentencepiece"""
 
-    def __init__(self, model_path: str, **kwargs):
+    def __init__(self, model_path: str, **kwargs) -> None:
         """
         Initializer for SentencepieceTokenizer.
 
@@ -25,12 +27,12 @@ class SentencepieceTokenizer(BaseTokenizer):
             raise ImportError(msg)
 
         super(SentencepieceTokenizer, self).__init__("sentencepiece")
-        self.tokenizer = sentencepiece.SentencePieceProcessor()
-        self.tokenizer.load(model_path)
+        self._tokenizer = sentencepiece.SentencePieceProcessor()
+        self._tokenizer.load(model_path)
 
-    def tokenize(self, text: str):
+    def tokenize(self, text: str) -> List[Token]:
         result = []
-        for subword in self.tokenizer.EncodeAsPieces(text):
+        for subword in self._tokenizer.EncodeAsPieces(text):
             token = Token(surface=subword)
             result.append(token)
         return result
